aboutsummaryrefslogtreecommitdiff
path: root/bpkg/rep-fetch.hxx
diff options
context:
space:
mode:
authorKaren Arutyunov <karen@codesynthesis.com>2018-03-12 19:21:01 +0300
committerKaren Arutyunov <karen@codesynthesis.com>2018-03-12 19:37:35 +0300
commitee16762d8435ec1a6dfe4a82655cde5624bb2c38 (patch)
tree338c5488966c1e7d35f5afa20e78f153443b1b32 /bpkg/rep-fetch.hxx
parent17ea04afcce1af129cac9dd2f840799a6e8b50eb (diff)
Add support for shallow fetch
Diffstat (limited to 'bpkg/rep-fetch.hxx')
-rw-r--r--bpkg/rep-fetch.hxx9
1 files changed, 6 insertions, 3 deletions
diff --git a/bpkg/rep-fetch.hxx b/bpkg/rep-fetch.hxx
index 030b192..18a50e9 100644
--- a/bpkg/rep-fetch.hxx
+++ b/bpkg/rep-fetch.hxx
@@ -51,14 +51,17 @@ namespace bpkg
bool ignore_unknown);
// Add (or update) repository locations to the configuration and fetch
// them. On failure clean up the configuration (see rep_remove_clean() for
// details). Note that it should be called in session.
//
void
rep_fetch (const common_options&,
const dir_path& conf,
database&,
- const vector<repository_location>&);
+ const vector<repository_location>&,
+ bool shallow);
}
#endif // BPKG_REP_FETCH_HXX
@@ -51,14 +51,17 @@ namespace bpkg
bool ignore_unknown);
// Add (or update) repository locations to the configuration and fetch
- // them. On failure clean up the configuration (see rep_remove_clean() for
- // details). Note that it should be called in session.
+ // them. If shallow is true, then don't fetch their prerequisite and/or
+ // complements unless the respective sets have changed. On failure clean up
+ // the configuration (see rep_remove_clean() for details). Note that it
+ // should be called in session.
//
void